@@ -6,6 +6,7 @@ from pathlib import Path
 from typing import Dict, List, Optional, Tuple
 
 from loguru import logger
+from pbt.config import PBTConfig
 from pbt.diff import RemoteDiff
 from pbt.package.graph import PkgGraph, ThirdPartyPackage
 from pbt.package.manager.manager import PkgManager, build_cache
@@ -29,8 +30,9 @@ class VersionConsistent(enum.Enum):
 
 
 class BTPipeline:
-    def __init__(self, root: Path, managers: Dict[PackageType, PkgManager]) -> None:
-        self.root = root
+    def __init__(self, cfg: PBTConfig, managers: Dict[PackageType, PkgManager]) -> None:
+        self.root = cfg.cwd
+        self.cfg = cfg
         self.managers = managers
         self.graph = PkgGraph()
         self.pkgs: Dict[str, Package] = {}
@@ -135,13 +137,12 @@ class BTPipeline:
         self,
         pkg_names: List[str],
         include_dev: bool = False,
-        editable: bool = False,
     ):
         """Install packages
 
         Args:
             pkg_names: name of packages to install
-            editable: whether to install those packages in editable mode
+            include_dev: whether to install development dependencies
         """
         pkgs = [self.pkgs[name] for name in pkg_names]
 
@@ -158,6 +159,7 @@ class BTPipeline:
                     and (
                         dep.name in pkg.dependencies or dep.name in pkg.dev_dependencies
                     )
+                    and (dep.name not in self.cfg.use_prebuilt_binaries)
                 ]
                 additional_deps = {
                     dep.name: next(iter(dep.invert_dependencies.values()))
@@ -170,7 +172,6 @@ class BTPipeline:
                 logger.info("Installing package: {}", pkg.name)
                 manager.install(
                     pkg,
-                    editable=editable,
                     include_dev=include_dev,
                     skip_deps=skip_deps,
                     additional_deps=additional_deps,
@@ -183,7 +184,7 @@ class BTPipeline:
                             dep.dev_dependencies.keys()
                         )
                         manager.install_dependency(
-                            pkg, dep, editable=editable, skip_dep_deps=skip_dep_deps
+                            pkg, dep, skip_dep_deps=skip_dep_deps
                         )
 
     def publish(self, pkg_names: List[str], registries: Dict[PackageType, PkgRegistry]):
